@@ -12,7 +12,7 @@
 #'      Exporting via \code{png("myplot.png", 600,400); colPoints(x,y,z); dev.off()} usually works much better
 #' @author Berry Boessenkool, \email{berry-b@@gmx.de}, 2011-2014. I'd be interested in hearing what you used the function for.
 #' @seealso \code{\link{classify}}, \code{\link{colPointsLegend}}, \code{\link{colPointsHist}}
-#' @references \url{http://uxblog.idvsolutions.com/2011/10/telling-truth.html},
+#' @references \url{https://archive.ph/EL9Vq},
 #'             \url{https://www.theusrus.de/blog/the-good-the-bad-22012/}
 #' @keywords aplot hplot color
 #' @importFrom grDevices colorRampPalette rainbow
@@ -274,8 +274,10 @@ if(zmat)
      cl$labels <- lv$labs[lv$sel]
      atgrey <- lv$all[lv$all >= 10^Range[1] & lv$all <= 10^Range[2]]
      }
-  image(x,y,t(z2), col=col, add=add, ylim=ylim, zlim=Range,
+  imargs <- list(x=x,y=y,z=t(z2), col=col, add=add, zlim=Range,
         xlab=xlab, ylab=ylab, las=las, axes=axes, log=log, ...)
+  imargs <- owa(list(ylim=ylim), imargs)
+  do.call(image, args=imargs)
   lines <- FALSE
   } else
 if(!add) plot(x, y, type="n", xlab=xlab, ylab=ylab, las=las, axes=axes, log=log, ...)
